@@ -24,7 +24,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QWidget>
 
 #include <QDialog>
-#include <KLocale>
 #include <QPushButton>
 #include <Solid/Device>
 
@@ -56,8 +55,8 @@ public:
     };
     enum ErrorCode {PinCodeTooShort, PinCodesDoNotMatch, PukCodeTooShort};
 
-    explicit PinDialog(ModemManager::Modem *modem, const Type type = SimPin, QWidget *parent=0);
-    ~PinDialog();
+    explicit PinDialog(ModemManager::Modem *modem, const Type type = SimPin, QWidget *parent = nullptr);
+    ~PinDialog() override;
 
     Type type() const;
     QString pin() const;
@@ -65,7 +64,7 @@ public:
     QString puk() const;
 
 public Q_SLOTS:
-    void accept();
+    void accept() override;
 
 private Q_SLOTS:
     void chkShowPassToggled(bool on);
