@@ -29,7 +29,7 @@ class Q_DECL_EXPORT Configuration : public QObject
 {
     Q_PROPERTY(bool unlockModemOnDetection READ unlockModemOnDetection WRITE setUnlockModemOnDetection)
     Q_PROPERTY(bool manageVirtualConnections READ manageVirtualConnections WRITE setManageVirtualConnections)
-    Q_PROPERTY(bool airplaneModeEnabled READ airplaneModeEnabled WRITE setAirplaneModeEnabled)
+    Q_PROPERTY(bool airplaneModeEnabled READ airplaneModeEnabled WRITE setAirplaneModeEnabled NOTIFY airplaneModeEnabledChanged)
     Q_PROPERTY(QString hotspotName READ hotspotName WRITE setHotspotName)
     Q_PROPERTY(QString hotspotPassword READ hotspotPassword WRITE setHotspotPassword)
     Q_PROPERTY(QString hotspotConnectionPath READ hotspotConnectionPath WRITE setHotspotConnectionPath)
@@ -38,25 +38,28 @@ class Q_DECL_EXPORT Configuration : public QObject
     Q_PROPERTY(bool showPasswordDialog READ showPasswordDialog CONSTANT)
     Q_OBJECT
 public:
-    static bool unlockModemOnDetection();
-    static void setUnlockModemOnDetection(bool unlock);
+    bool unlockModemOnDetection();
+    void setUnlockModemOnDetection(bool unlock);
 
-    static bool manageVirtualConnections();
-    static void setManageVirtualConnections(bool manage);
+    bool manageVirtualConnections();
+    void setManageVirtualConnections(bool manage);
 
-    static bool airplaneModeEnabled();
-    static void setAirplaneModeEnabled(bool enabled);
+    bool airplaneModeEnabled() const;
+    void setAirplaneModeEnabled(bool enabled);
+    Q_SIGNAL void airplaneModeEnabledChanged();
 
-    static QString hotspotName();
-    static void setHotspotName(const QString &name);
+    QString hotspotName();
+    void setHotspotName(const QString &name);
 
-    static QString hotspotPassword();
-    static void setHotspotPassword(const QString &password);
+    QString hotspotPassword();
+    void setHotspotPassword(const QString &password);
 
-    static QString hotspotConnectionPath();
-    static void setHotspotConnectionPath(const QString &path);
+    QString hotspotConnectionPath();
+    void setHotspotConnectionPath(const QString &path);
 
-    static bool showPasswordDialog();
+    bool showPasswordDialog();
+
+    static Configuration &self();
 };
 
 #endif // PLAMA_NM_CONFIGURATION_H
